OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не могу да уписујем у „config“ директоријум!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Ово обично може да се поправи тако што се веб серверу дозволи упис у config директоријум.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Али, ако радије желите да фајл config.php може само да се чита, онда у њему поставите опцију „config_is_read_only” на true.",
    "See %s" : "Погледајте %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Не постоји апликација %1$s или њена верзија није компатибилна са овим сервером. Молимо вас да проверите директоријум са апликацијама.",
    "Sample configuration detected" : "Откривен је пример подешавања",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Откривено је да је прекопиран пример подешавања. Ово може покварити инсталацију и није подржано. Прочитајте документацију пре вршења промена у фајлу config.php",
    "The page could not be found on the server." : "На серверу не може да се пронађе ова страница.",
    "%s email verification" : "%s потврђивање и-мејла",
    "Email verification" : "Потврђивање и-мејла",
    "Click the following button to confirm your email." : "Кликните на наредно дугме да потврдите свој и-мејл.",
    "Click the following link to confirm your email." : "Кликните на следећи линк да потврдите свој и-мејл.",
    "Confirm your email" : "Потврдите свој и-мејл",
    "Other activities" : "Остале активности",
    "%1$s and %2$s" : "%1$s и %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
    "Education bundle" : "Образовни пакет",
    "Enterprise bundle" : "Комплет за предузећа",
    "Groupware bundle" : "Комплет за радне тимове",
    "Hub bundle" : "Чвориште пакета",
    "Public sector bundle" : "Пакет за јавни сектор",
    "Social sharing bundle" : "Комплет за друштвене мреже",
    "PHP %s or higher is required." : "Потребан је PHP %s или новији.",
    "PHP with a version lower than %s is required." : "Потребна је PHP верзија старија од верзије %s.",
    "%sbit or higher PHP required." : "Потребна је верзија PHP-а једнака или већа од верзије %s.",
    "The following architectures are supported: %s" : "Подржане су следеће архитектуре: %s",
    "The following databases are supported: %s" : "Подржане су следеће базе података: %s",
    "The command line tool %s could not be found" : "Алатку командне линије „%s“ није могуће пронаћи",
    "The library %s is not available." : "Библиотека „%s“ није доступна.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Потребна је библиотека „%1$s“ верзије веће од %2$s - доступна верзија је %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Потребна је библиотека „%1$s“ верзије ниже од %2$s - доступна верзија је %3$s.",
    "The following platforms are supported: %s" : "Подржане су следеће платформе: %s",
    "Server version %s or higher is required." : "Потребна је верзија сервера %s или виша.",
    "Server version %s or lower is required." : "Потребна је верзија сервера %s или нижа.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Пријављени налог мора бити админ, подадмин или мора да поседује специјално право да приступи овом подешавању",
    "Your current IP address doesn't allow you to perform admin actions" : "Ваша тренутна IP адреса не дозвољава да извршавате админ радње",
    "Logged in account must be an admin or sub admin" : "Пријављени налог мора бити админ или подадмин",
    "Logged in account must be an admin" : "Пријављени налог мора бити админ",
    "Wiping of device %s has started" : "Започето брисање уређаја %s",
    "Wiping of device »%s« has started" : "Удаљено брисање уређаја „%s“ је почело",
    "»%s« started remote wipe" : "„%s“ је започео удаљено брисање",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Уређај или апликација „%s“ је започео процес удаљеног брисања. Добићете још један и-мејл када се процес заврши.",
    "Wiping of device %s has finished" : "Брисање уређаја %s завршено",
    "Wiping of device »%s« has finished" : "Брисање уређаја „%s“ завршено",
    "»%s« finished remote wipe" : "„%s“ је завршио удаљено брисање",
    "Device or application »%s« has finished the remote wipe process." : "Уређај или апликација „%s“ је завршио процес удаљеног брисања.",
    "Remote wipe started" : "Започето удаљено брисање",
    "A remote wipe was started on device %s" : "Започето удаљено брисање на уређају %s",
    "Remote wipe finished" : "Удаљено брисање завршено",
    "The remote wipe on %s has finished" : "Удаљено брисање на уређају %s завршено",
    "Authentication" : "Провера идентитета",
    "Unknown filetype" : "Непознат тип фајла",
    "Invalid image" : "Неисправна слика",
    "Avatar image is not square" : "Слика аватара није квадратна",
    "Files" : "Фајлови",
    "View profile" : "Погледај профил",
    "same time" : "исто време",
    "_%nh_::_%nh_" : ["%nч","%nч","%nч"],
    "_%nm_::_%nm_" : ["%nм","%nм","%nм"],
    "%s ahead" : "%s испред",
    "%s behind" : "%s иза",
    "Local time: %s" : "Локално време: %s",
    "today" : "данас",
    "tomorrow" : "сутра",
    "yesterday" : "јуче",
    "_in %n day_::_in %n days_" : ["за %n дан","за %n дана","за %n дана"],
    "_%n day ago_::_%n days ago_" : ["пре %n дан","пре %n дана","пре %n дана"],
    "next month" : "следећег месеца",
    "last month" : "прошлог месеца",
    "_in %n month_::_in %n months_" : ["за %n месец","за %n месеца","за %n месеци"],
    "_%n month ago_::_%n months ago_" : ["пре %n месец","пре %n месеца","пре %n месеци"],
    "next year" : "следеће године",
    "last year" : "прошле године",
    "_in %n year_::_in %n years_" : ["за %n годину","за %n године","за %n година"],
    "_%n year ago_::_%n years ago_" : ["пре %n годину","пре %n године","пре %n година"],
    "_in %n hour_::_in %n hours_" : ["за %n сат","за %n сата","за %n сати"],
    "_%n hour ago_::_%n hours ago_" : ["пре %n сат","пре %n сата","пре %n сати"],
    "_in %n minute_::_in %n minutes_" : ["за %n минут","за %n минута","за %n минута"],
    "_%n minute ago_::_%n minutes ago_" : ["пре %n минут","пре %n минута","пре %n минута"],
    "in a few seconds" : "за пар секунди",
    "seconds ago" : "пре неколико секунди",
    "Empty file" : "Празан фајл",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул са идентификацијом: %s не постоји. Омогућите га у подешавањима апликација или контактирајте администратора.",
    "No file conversion providers available" : "Није доступан ниједан пружалац услуге конверзије фајла",
    "File is too large to convert" : "Фајл је сувише велики да би могао да се конвертује",
    "Destination does not match conversion extension" : "Одредиште не одговара екстензији конверзије",
    "Could not convert file" : "Фајл није могао да се конвертује",
    "Destination does not exist" : "Одредиште не постоји",
    "Destination is not creatable" : "Одредиште не може да се креира",
    "Dot files are not allowed" : "Фајлови са почетном тачком нису дозвољени",
    "%1$s (renamed)" : "%1$s (преименован)",
    "renamed file" : "преименован фајл",
    "\"%1$s\" is a forbidden file or folder name." : "„%1$s” је забрањено име фајла или фолдера.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "„%1$s” је забрањени префикс имена фајла или фолдера.",
    "\"%1$s\" is not allowed inside a file or folder name." : "„%1$s” није дозвољено у имену фајла или фолдера.",
    "\"%1$s\" is a forbidden file type." : "„%1$s” је забрањен тип фајла.",
    "Filenames must not end with \"%1$s\"." : "Имена фајлова не смеју да се завршавају са „%1$s”.",
    "Invalid parent path" : "Неисправна путања родитеља",
    "File already exists" : "Фајл већ постоји",
    "Invalid path" : "Неисправна путања",
    "Failed to create file from template" : "Није успело креирање фајла из шаблона",
    "Templates" : "Шаблони",
    "Storage %s cannot be moved" : "Складиште %s не може да се премести",
    "Moving a share (%s) into a shared folder is not allowed" : "Није дозвољено премештање дељења (%s) у дељени фолдер",
    "Moving a storage (%s) into a shared folder is not allowed" : "Није дозвољено премештање складишта (%s) у дељени фолдер",
    "Moving a share (%s) into another share (%s) is not allowed" : "Није дозвољено премештање дељења (%s) у друго дељење (%s)",
    "Moving a share (%s) into another storage (%s) is not allowed" : "Није дозвољено премештање дељења (%s) у друго складиште (%s)",
    "Moving a storage (%s) into a share (%s) is not allowed" : "Није дозвољено премештање складишта (%s) у дељење (%s)",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "Није дозвољено премештање складишта (%s) у друго складиште (%s)",
    "Path contains invalid segments" : "Путања садржи неисправне сегменте",
    "Filename is a reserved word" : "Име фајла је резервисана реч",
    "Filename contains at least one invalid character" : "Назив фајла садржи бар један недозвољен знак",
    "Filename is too long" : "Име фајла је сувише дугачко",
    "Empty filename is not allowed" : "Празан назив није дозвољен",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Апликација \"%s\" не може бити инсталирана јер appinfo фајл не може да се прочита.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Апликација \"%s\" не може бити инсталирана јер није компатибилна са овом верзијом сервера.",
    "__language_name__" : "Српски",
    "This is an automatically sent email, please do not reply." : "Ово је аутоматски генерисана порука, не одговарајте на њу.",
    "Help & privacy" : "Помоћ и приватност",
    "Appearance and accessibility" : "Изглед и приступачност",
    "Apps" : "Апликације",
    "Personal settings" : "Лична подешавања",
    "Administration settings" : "Административна подешавања",
    "Settings" : "Поставке",
    "Log out" : "Одјава",
    "Accounts" : "Налози",
    "Bluesky" : "Bluesky",
    "View %s on Bluesky" : "Прикажи %s на Bluesky",
    "Email" : "Е-пошта",
    "Mail %s" : "Пошта %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Погледај %s на fediverse",
    "Phone" : "Телефон",
    "Call %s" : "Позив %s",
    "Twitter" : "Твитер",
    "View %s on Twitter" : "Погледај %s на Твитеру",
    "Website" : "Веб страна",
    "Visit %s" : "Посети %s",
    "Address" : "Адреса",
    "Profile picture" : "Слика профила",
    "About" : "О програму",
    "Display name" : "Име за приказ",
    "Headline" : "Наслов",
    "Organization" : "Организација",
    "Role" : "Улога",
    "Pronouns" : "Заменице",
    "Unknown account" : "Непознати налог",
    "Additional settings" : "Додатне поставке",
    "Enter the database Login and name for %s" : "Унесите име за пријаву на базу података и назив за %s",
    "Enter the database Login for %s" : "Унесите име за пријаву на базу података за %s",
    "Enter the database name for %s" : "Унесите назив базе података за %s",
    "You cannot use dots in the database name %s" : "У називу базе података не можете да користите тачке %s",
    "MySQL Login and/or password not valid" : "MySQL име за пријаву и/или лозинка нису исправни",
    "You need to enter details of an existing account." : "Потребно је да унесете детаље постојећег налога.",
    "Oracle connection could not be established" : "Веза са базом података Oracle не може бити успостављена",
    "Oracle Login and/or password not valid" : "Oracle име за пријаву и/или лозинка нису исправни",
    "PostgreSQL Login and/or password not valid" : "PostgreSQL име за пријаву и/или лозинка нису исправни",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X није подржан и %s неће радити исправно на овој платформи. Користите га на сопствени ризик!",
    "For the best results, please consider using a GNU/Linux server instead." : "За најбоље резултате, размотрите употребу ГНУ/Линукс сервера.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Изгледа да %s ради у 32-битном PHP окружењу а open_basedir је подешен у php.ini фајлу. То може довести до проблема са фајловима већим од 4 GB, те стога није препоручљиво.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Уклоните open_basedir поставку из php.ini фајла или пређите на 64-битни PHP.",
    "Set an admin Login." : "Поставите име за пријаву админа.",
    "Set an admin password." : "Поставите лозинку за администратора.",
    "Cannot create or write into the data directory %s" : "Не може да се креира или уписује у директоријум са подацима %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Позадина дељења %s мора користити корисничко окружење OCP\\Share_Backend",
    "Sharing backend %s not found" : "Позадина за дељење %s није пронађена",
    "Sharing backend for %s not found" : "Позадина за дељење за %s није пронађена",
    "%1$s shared %2$s with you" : "%1$s је поделио „%2$s” са вама",
    "Open %s" : "Отвори %s",
    "%1$s via %2$s" : "%1$s преко %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s је поделио %2$s са вама и жели да дода:",
    "%1$s shared %2$s with you and wants to add" : "%1$s је поделио %2$s са вама и жели да дода",
    "%s added a note to a file shared with you" : "%s је додао белешку на фајл који је поделио са вама",
    "Passwords are enforced for link and mail shares" : "За дељења линком и поштом је обавезна заштита лозинком",
    "Share recipient is not a valid user" : "Прималац дељења није важећи корисник",
    "Share recipient is not a valid group" : "Прималац дељења није важећа група",
    "Share recipient should be empty" : "Прималац дељења би требало да буде празно",
    "Share recipient should not be empty" : "Прималац дељења не би требало да буде празно",
    "Share recipient is not a valid circle" : "Прималац дељења није важећи круг",
    "Unknown share type" : "Непознат тип дељења",
    "Share initiator must be set" : "Мора да се постави иницијатор дељења",
    "Cannot share with yourself" : "Не можете да делите са самим собом",
    "Shared path must be set" : "Мора да се постави путања дељења",
    "Shared path must be either a file or a folder" : "Путања дељења мора да буде или фајл или фолдер",
    "You cannot share your root folder" : "Не можете да делите свој корени фолдер",
    "You are not allowed to share %s" : "Није вам дозвољено да делите %s",
    "Valid permissions are required for sharing" : "За дељење су неопходне исправне дозволе",
    "File shares cannot have create or delete permissions" : "Фајлови не могу да се деле са дозволама за креирање или брисање",
    "Cannot increase permissions of %s" : "Не могу да повећам привилегије за %s",
    "Shares need at least read permissions" : "Дељења морају да имају барем право читања",
    "Files cannot be shared with delete permissions" : "Фајлови не могу да се деле са дозволама за брисање",
    "Files cannot be shared with create permissions" : "Фајлови не могу да се деле са дозволама за креирање",
    "Expiration date is in the past" : "Датум истека је у прошлости",
    "Expiration date is enforced" : "Форсиран је датум истека",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Датум истека не може да се постави више од %n дан у будућност","Датум истека не може да се постави више од %n дана у будућност","Датум истека не може да се постави више од %n дана у будућност"],
    "Sharing is only allowed with group members" : "Дељење је дозвољено само са члановима групе",
    "Sharing %s failed, because this item is already shared with the account %s" : "Дељење %s није успело зато што се ова ставка већ дели са налогом %s",
    "Group sharing is now allowed" : "Сада је дозвољено дељење са групом",
    "Sharing is only allowed within your own groups" : "Дељење је дозвољено само унутар ваших група",
    "Path is already shared with this group" : "Путања се већ дели са овом групом",
    "Link sharing is not allowed" : "Није дозвољено дељење линком",
    "Public upload is not allowed" : "Није дозвољено јавно отпремање",
    "You cannot share a folder that contains other shares" : "Не можете да делите фолдер који садржи друга дељења",
    "Sharing is disabled" : "Дељење је искључено",
    "Sharing is disabled for you" : "Дељење је за вас искључено",
    "Cannot share with the share owner" : "Не може да се дели са власником дељења",
    "Share does not have a full ID" : "Дељење не поседује комплетан ID",
    "Cannot change share type" : "Тип дељења не може да се промени",
    "Can only update recipient on user shares" : "На корисничким дељењима може да се ажурира само прималац",
    "Cannot enable sending the password by Talk with an empty password" : "Празном лозинком не може да се укључи слање лозинке апликацијом Talk",
    "Cannot enable sending the password by Talk without setting a new password" : "Без постављања нове лозинке не може да се укључи слање лозинке апликацијом Talk",
    "Cannot disable sending the password by Talk without setting a new password" : "Без постављања нове лозинке не може да се искључи слање лозинке апликацијом Talk",
    "Share provider does not support accepting" : "Пружалац услуге дељења не подржава прихватање",
    "Cannot change target of link share" : "Не може да се промени циљ дељења линком",
    "Invalid share recipient" : "Неисправан прималац дељења",
    "Group \"%s\" does not exist" : "Група „%s” не постоји",
    "The requested share does not exist anymore" : "Захтевано дељење више не постоји",
    "The requested share comes from a disabled user" : "Захтевано дељење долази од искљученог корисника",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Корисник није креиран јер је достигнуто ограничење броја корисника. За више детаља, погледајте своја обавештења.",
    "Could not find category \"%s\"" : "Не могу да пронађем категорију „%s“.",
    "Input text" : "Унос текста",
    "The input text" : "Унесени текст",
    "Sunday" : "Недеља",
    "Monday" : "Понедељак",
    "Tuesday" : "Уторак",
    "Wednesday" : "Среда",
    "Thursday" : "Четвртак",
    "Friday" : "Петак",
    "Saturday" : "Субота",
    "Sun." : "Нед",
    "Mon." : "Пон",
    "Tue." : "Уто",
    "Wed." : "Сре",
    "Thu." : "Чет",
    "Fri." : "Пет",
    "Sat." : "Суб",
    "Su" : "Не",
    "Mo" : "По",
    "Tu" : "Ут",
    "We" : "Ср",
    "Th" : "Че",
    "Fr" : "Пе",
    "Sa" : "Су",
    "January" : "Јануар",
    "February" : "Фебруар",
    "March" : "Март",
    "April" : "Април",
    "May" : "Мај",
    "June" : "Јун",
    "July" : "Јул",
    "August" : "Август",
    "September" : "Септембар",
    "October" : "Октобар",
    "November" : "Новембар",
    "December" : "Децембар",
    "Jan." : "Јан.",
    "Feb." : "Феб.",
    "Mar." : "Мар.",
    "Apr." : "Апр.",
    "May." : "Мај.",
    "Jun." : "Јун.",
    "Jul." : "Јул.",
    "Aug." : "Авг.",
    "Sep." : "Сеп.",
    "Oct." : "Окт.",
    "Nov." : "Нов.",
    "Dec." : "Дец.",
    "A valid password must be provided" : "Морате унети исправну лозинку",
    "The Login is already being used" : "Ово име за пријаву се већ користи",
    "Could not create account" : "Налог није могао да се креира ",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "У имену за пријаву су дозвољени само следећи карактери: „a-z”, „A-Z”, „0-9”, размаци и „_.@-'",
    "A valid Login must be provided" : "Морате да унесете исправно име за пријаву",
    "Login contains whitespace at the beginning or at the end" : "Име за пријаву садржи белине на почетку или на крају",
    "Login must not consist of dots only" : "Име за пријаву не може да се састоји само од тачака",
    "Username is too long" : "Корисничко име је сувише дугачко",
    "Login is invalid because files already exist for this user" : "Име за пријаву није исправно пошто већ постоје фајлови овог корисника",
    "Account disabled" : "Налог је искључен",
    "Login canceled by app" : "Пријава отказана од стране апликације",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Апликација „%1$s“ не може бити инсталирана јер следеће зависности нису испуњене: %2$s",
    "a safe home for all your data" : "сигурно место за све Ваше податке",
    "Application is not enabled" : "Апликација није укључена",
    "Authentication error" : "Грешка при провери идентитета",
    "Token expired. Please reload page." : "Жетон је истекао. Поново учитајте страницу.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Нема драјвера базе података (скулајт, мајскул или постгрескул).",
    "Cannot write into \"config\" directory." : "Не може да се упише у „config директоријум.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у config директоријум. Погледајте %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, ако пре желите да задржите config.php да је само за читање, поставите опцију \"config_is_read_only\" на true у њему самом. Погледајте %s",
    "Cannot create \"data\" directory." : "Не може да се креира „data” директоријум.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у корени директоријум. Погледајте %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Проблем са дозволама обично може да се поправи тако што се веб серверу дозволи право уписа у корени директоријум. Погледајте %s.",
    "Your data directory is not writable." : "У ваш директоријум са подацима не може да се упише.",
    "Setting locale to %s failed." : "Није успело постављање локалитета на %s.",
    "Please install one of these locales on your system and restart your web server." : "Молимо вас да на свој систем инсталирате један од следећих локалитета и поново покренете свој веб сервер.",
    "PHP module %s not installed." : "PHP модул %s није инсталиран.",
    "Please ask your server administrator to install the module." : "Замолите администратора вашег сервера да инсталира тај модул.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставка „%s“ није постављена на „%s“.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Некстклауд ће прорадити поново када прилагодите ово подашавање у php.ini фајлу",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP је очигледно подешен да склања уметнуте doc блокове. То ће учинити неколико кључних апликација недоступним.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ово је вероватно изазвано кешом или акцелератором као што су ЗендОПкеш или еАкцелератор.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP модули су инсталирани али се и даље воде као недостајући?",
    "Please ask your server administrator to restart the web server." : "Замолите вашег администратора сервера да поново покрене веб сервер.",
    "The required %s config variable is not configured in the config.php file." : "У config.php фајлу није подешена потребна config променљива %s.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Молимо вас да замолите свог систем администратора да провери Некстклауд конфигурацију.",
    "Your data directory is readable by other people." : "Ваш директоријум са подацима могу да читају друге особе.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Молимо вас да промените дозволе у 0770 тако да друге особе немају право да прикажу његов садржај.",
    "Your data directory must be an absolute path." : "Ваш директоријум са подацима мора бити апсолутна путања.",
    "Check the value of \"datadirectory\" in your configuration." : "Проверите вредност „datadirectory” у својој конфигурацији.",
    "Your data directory is invalid." : "Ваш директоријум са подацима је неисправан.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Обезбедите да се у корену директоријум података налази фајл под називом „%1$s”. Он би требало да има следећи садржај: „%2$s”",
    "Action \"%s\" not supported or implemented." : "Радња \"%s\" није подржана или имплементирана.",
    "Authentication failed, wrong token or provider ID given" : "Неуспела провера идентитета, добијен погрешан токен или ID провајдера",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Недостају параметри да би се довршио захтев. Недостајући параметри: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Идентификацију \"%1$s\" већ користи провајдер здруживања \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Провајдер клауд здруживања са ID-ом \"%s\" не постоји",
    "Could not obtain lock type %d on \"%s\"." : "Не могу да остварим закључаност %d за „%s“.",
    "Storage unauthorized. %s" : "Складиште није овлашћено. %s",
    "Storage incomplete configuration. %s" : "Непотпуна конфигурација складишта. %s",
    "Storage connection error. %s" : "Грешка приликом повезивања на складиште. %s",
    "Storage is temporarily not available" : "Складиште привремено није  доступно",
    "Storage connection timeout. %s" : "Истекло је време за повезивање на складиште. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Ако желите да се ова провера изврши, морате обезбедити да ваш веб сервер може да се повеже на самог себе. То значи да мора бити у стању да разреши и да се повеже барем на један од својих `trusted_domains` или `overwrite.cli.url`. Ова грешка може да буде резултат DNS неподударања на страни сервера или одлазно правило заштитног зида.",
    "Analyze images" : "Анализирај слике",
    "Ask a question about the given images." : "Поставите питање у вези са датим сликама.",
    "Images" : "Слике",
    "Images to ask a question about" : "Слике о којим се постављају питања",
    "Question" : "Питање",
    "What to ask about the images." : "Шта да се пита у вези са сликама.",
    "Generated response" : "Генерисани одговор",
    "The answer to the question" : "Одговор на питање",
    "Audio chat" : "Аудио чет",
    "Voice chat with the assistant" : "Гласовни чет са асистентом",
    "System prompt" : "Кориснички захтев",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Дефинишите правила и претпоставке које би асистент требало да следи током разговора.",
    "Chat voice message" : "Чет говорна порука",
    "Describe a task that you want the assistant to do or ask a question." : "Опишите задатак који желите да асистент обави или поставите питање.",
    "Chat history" : "Историју чета",
    "The history of chat messages before the current message, starting with a message by the user." : "Историја чет порука пре текуће поруке, почевши са поруком корисника.",
    "Input transcript" : "Транскрипт уноса",
    "Transcription of the audio input" : "Транскрипт аудио улаза",
    "Response voice message" : "Гласовна порука одговора",
    "The generated voice response as part of the conversation" : "Генерисани гласовни одговор као део разговора",
    "Output transcript" : "Транскрипт излаза",
    "Transcription of the audio output" : "Транскрипција аудио излаза",
    "Transcribe audio" : "Транскрибуј звук",
    "Transcribe the things said in an audio" : "Транскрибује оно што се каже у звуку",
    "Audio input" : "Аудио улаз",
    "The audio to transcribe" : "Звук који треба да се транскрибује",
    "Transcription" : "Транскрипција",
    "The transcribed text" : "Транскрибовани текст",
    "Chat by voice with an agent" : "Гласовни чет са агентом",
    "Describe a task that you want the agent to do or ask a question." : "Опишите задатак који желите да агент обави или поставите питање.",
    "Confirmation" : "Потврда",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Да ли да се потврде претходно затражене акције: 0 за одбијање и 1 за потврђивње.",
    "Conversation token" : "Жетон разговора",
    "A token representing the conversation." : "Жетон који представља разговор.",
    "The new conversation token" : "Нови жетон разговора",
    "Send this along with the next interaction." : "Пошаљи ово уз наредну интеракцију.",
    "Requested actions by the agent" : "Акције које је захтевао агент",
    "Actions that the agent would like to carry out in JSON format." : "Акције које би агент желео да изврши у JSON формату.",
    "Chat with an agent" : "Ћаскај са агентом",
    "Chat message" : "Чет порука",
    "A chat message to send to the agent." : "Порука која треба да се пошаље агенту.",
    "The response from the chat model." : "Одговор чет модела.",
    "Context write" : "Писање контекста",
    "Writes text in a given style based on the provided source material." : "Пише текст у датом стилу заснован на наведеном изворном материјалу.",
    "Writing style" : "Стил писања",
    "Demonstrate a writing style that you would like to immitate" : "Демонстрирајте стил писања који желите да се имитира",
    "Source material" : "Изворни материјал",
    "The content that would like to be rewritten in the new writing style" : "Садржај који бисте желели да се поново испише у новом стилу писања",
    "Generated text" : "Генерисани текст",
    "The generated text with content from the source material in the given style" : "Генерисани текст са садржајем изворног материјала у наведеном стилу",
    "Emoji generator" : "Емођи генератор",
    "Takes text and generates a representative emoji for it." : "Прихвата текст и генерише емођи који га представља.",
    "The text to generate an emoji for" : "Текст за који желите да се генерише емођи",
    "Generated emoji" : "Генерисани емођи",
    "The generated emoji based on the input text" : "Емођи генерисан на основу улазног текста",
    "Generate image" : "Генериши слику",
    "Generate an image from a text prompt" : "Генерише слику на основу унетог текста",
    "Prompt" : "Захтев за унос",
    "Describe the image you want to generate" : "Опишите слику коју желите да генеришете",
    "Number of images" : "Број слика",
    "How many images to generate" : "Колико слика желите да се генерише",
    "Output images" : "Излазне слике",
    "The generated images" : "Генерисане слике",
    "Generate speech" : "Генериши говор",
    "Generate speech from a transcript" : "Генерише говор из транскрипта",
    "Write transcript that you want the assistant to generate speech from" : "Напишите транскрипт из којег желите да асистент генерише говор",
    "Output speech" : "Излазни говор",
    "The generated speech" : "Генерисани говор",
    "Free text to text prompt" : "Произвољни текст као унос",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Извршава произвољни захтев кроз језички модел који затим враћа одговор",
    "Describe a task that you want the assistant to do or ask a question" : "Опишите задатак који желите да обави асистент или поставите питање",
    "Generated reply" : "Генерисани одговор",
    "The generated text from the assistant" : "Текст који је генерисао асистент",
    "Change Tone" : "Измени тон",
    "Change the tone of a piece of text." : "Мења тон дела текста.",
    "Write a text that you want the assistant to rewrite in another tone." : "Напишите текст који желите да асистент реформулише другачијим тоном.",
    "Desired tone" : "Жељени тон",
    "In which tone should your text be rewritten?" : "Каквим тоном желите да реформулишете свој текст?",
    "The rewritten text in the desired tone, written by the assistant:" : "Реформулисани текст у траженом тону који је написао асистент:",
    "Chat" : "Ћаскање",
    "Chat with the assistant" : "Ћаскање са асистентом",
    "The history of chat messages before the current message, starting with a message by the user" : "Историја чет порука пре текуће поруке, почевши са поруком корисника",
    "Response message" : "Порука одговора",
    "The generated response as part of the conversation" : "Генерисани  одговор као део разговора",
    "Chat with tools" : "Чет са алатима",
    "Chat with the language model with tool calling support." : "Чет са језичким моделом који подржава позивање алата.",
    "Tool message" : "Алатна порука",
    "The result of tool calls in the last interaction" : "Резултат позива алата у последњој интеракцији",
    "Available tools" : "Доступни алати",
    "The available tools in JSON format" : "Листа доступних алата у JSON  формату",
    "The response from the chat model" : "Одговор чет модела",
    "Tool calls" : "Позиви алата",
    "Tools call instructions from the model in JSON format" : "Инструкције за позив алата из модела у JSON формату",
    "Formalize text" : "Формализуј текст",
    "Takes a text and makes it sound more formal" : "Узима текст и реформулише га тако да постане формалнији",
    "Write a text that you want the assistant to formalize" : "Напишите текст који желите да асистент формализује",
    "Formalized text" : "Формализован текст",
    "The formalized text" : "Формализовани текст",
    "Generate a headline" : "Генериши наслов",
    "Generates a possible headline for a text." : "Генерише могућу насловну линију текста.",
    "Original text" : "Оригинални текст",
    "The original text to generate a headline for" : "Оригинални текст за који се генерише наслов",
    "The generated headline" : "Генерисани наслов",
    "Proofread" : "Лектура",
    "Proofreads a text and lists corrections" : "Лекторише текст и исписује листу исправки",
    "Text" : "Текст",
    "The text to proofread" : "Текст који треба да се лекторише",
    "Corrections" : "Исправке",
    "The corrections that should be made in your text" : "Исправке које треба да се ураде над вашим текстом",
    "Reformulate text" : "Реформулиши текст",
    "Takes a text and reformulates it" : "Узима текст и реформулише га",
    "Write a text that you want the assistant to reformulate" : "Напишите текст који желите да асистент реформулише",
    "Reformulated text" : "Реформулисани текст",
    "The reformulated text, written by the assistant" : "Реформулисани текст који је написао асистент",
    "Simplify text" : "Упрости текст",
    "Takes a text and simplifies it" : "Узима текст и упрошћава га",
    "Write a text that you want the assistant to simplify" : "Напишите текст који желите да асистент упрости",
    "Simplified text" : "Упрошћени текст",
    "The simplified text" : "Поједностављени текст",
    "Summarize" : "Резимирај",
    "Summarizes a text" : "Прави резиме текста",
    "The original text to summarize" : "Оригинални текст који се резимира",
    "Summary" : "Сумарно",
    "The generated summary" : "Генерисани резиме",
    "Extract topics" : "Издвој теме",
    "Extracts topics from a text and outputs them separated by commas" : "Издваја теме из текста и исписује их раздвојене запетама",
    "The original text to extract topics from" : "Оригинални текст из којег се издвајају теме",
    "Topics" : "Теме",
    "The list of extracted topics" : "Листа издвојених тема",
    "Translate" : "Превођење",
    "Translate text from one language to another" : "Преводи текст са једног језика на други",
    "Origin text" : "Изворни текст",
    "The text to translate" : "Текст који треба да се преведе",
    "Origin language" : "Изворни језик",
    "The language of the origin text" : "Језик изворног текста",
    "Target language" : "Циљни језик",
    "The desired language to translate the origin text in" : "Жељени језик на који треба да се преведе изворни текст",
    "Result" : "Резултат",
    "The translated text" : "Преведени текст",
    "Free prompt" : "Произвољни захтев",
    "Runs an arbitrary prompt through the language model." : "Извршава произвољни захтев кроз језички модел.",
    "Generate headline" : "Генериши линију наслова",
    "Summarizes text by reducing its length without losing key information." : "Резимира текст тако што га скраћује без губитка кључних информација.",
    "Extracts topics from a text and outputs them separated by commas." : "Издваја теме из текста и исписује их раздвојене запетама.",
    "Organisation" : "Организација",
    "Login is too long" : "Име за пријаву је сувише дугачко",
    "Cannot write into \"apps\" directory." : "Не може да се упише у „apps” директоријум.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ово обично може да се поправи тако што се веб серверу дозволи право уписа у apps директоријум или тако што се искључи Продавница апликација у config фајлу.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> је постављено на <code>%s</code> уместо на очекивану вредност <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Да бисте исправили овај проблем, поставите <code>mbstring.func_overload</code> на <code>0</code> у свом php.ini фајлу."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
